LANGUAGES_OPTIONS = [
    {"label": "Afrikaans", "value": "af"},
    {"label": "Arabic", "value": "ar"},
    {"label": "Bengali", "value": "bn"},
    {"label": "Bosnian", "value": "bs"},
    {"label": "Catalan", "value": "ca"},
    {"label": "Czech", "value": "cs"},
    {"label": "Welsh", "value": "cy"},
    {"label": "Danish", "value": "da"},
    {"label": "German", "value": "de"},
    {"label": "Greek", "value": "el"},
    {"label": "English", "value": "en"},
    {"label": "English (Australia)", "value": "en-au"},
    {"label": "English (Canada)", "value": "en-ca"},
    {"label": "English (UK)", "value": "en-gb"},
    {"label": "English (Ghana)", "value": "en-gh"},
    {"label": "English (Ireland)", "value": "en-ie"},
    {"label": "English (India)", "value": "en-in"},
    {"label": "English (Nigeria)", "value": "en-ng"},
    {"label": "English (New Zealand)", "value": "en-nz"},
    {"label": "English (Philippines)", "value": "en-ph"},
    {"label": "English (Tanzania)", "value": "en-tz"},
    {"label": "English (UK)", "value": "en-uk"},
    {"label": "English (US)", "value": "en-us"},
    {"label": "English (South Africa)", "value": "en-za"},
    {"label": "Esperanto", "value": "eo"},
    {"label": "Spanish", "value": "es"},
    {"label": "Spanish (Spain)", "value": "es-es"},
    {"label": "Spanish (US)", "value": "es-us"},
    {"label": "Estonian", "value": "et"},
    {"label": "Finnish", "value": "fi"},
    {"label": "French", "value": "fr"},
    {"label": "French (Canada)", "value": "fr-ca"},
    {"label": "French (France)", "value": "fr-fr"},
    {"label": "Hindi", "value": "hi"},
    {"label": "Croatian", "value": "hr"},
    {"label": "Hungarian", "value": "hu"},
    {"label": "Armenian", "value": "hy"},
    {"label": "Indonesian", "value": "id"},
    {"label": "Icelandic", "value": "is"},
    {"label": "Italian", "value": "it"},
    {"label": "Japanese", "value": "ja"},
    {"label": "Javanese", "value": "jw"},
    {"label": "Khmer", "value": "km"},
    {"label": "Korean", "value": "ko"},
    {"label": "Latin", "value": "la"},
    {"label": "Latvian", "value": "lv"},
    {"label": "Macedonian", "value": "mk"},
    {"label": "Malayalam", "value": "ml"},
    {"label": "Marathi", "value": "mr"},
    {"label": "Myanmar (Burmese)", "value": "my"},
    {"label": "Nepali", "value": "ne"},
    {"label": "Dutch", "value": "nl"},
    {"label": "Norwegian", "value": "no"},
    {"label": "Polish", "value": "pl"},
    {"label": "Portuguese", "value": "pt"},
    {"label": "Portuguese (Brazil)", "value": "pt-br"},
    {"label": "Portuguese (Portugal)", "value": "pt-pt"},
    {"label": "Romanian", "value": "ro"},
    {"label": "Russian", "value": "ru"},
    {"label": "Sinhala", "value": "si"},
    {"label": "Slovak", "value": "sk"},
    {"label": "Albanian", "value": "sq"},
    {"label": "Serbian", "value": "sr"},
    {"label": "Sundanese", "value": "su"},
    {"label": "Swedish", "value": "sv"},
    {"label": "Swahili", "value": "sw"},
    {"label": "Tamil", "value": "ta"},
    {"label": "Telugu", "value": "te"},
    {"label": "Thai", "value": "th"},
    {"label": "Tagalog (Filipino)", "value": "tl"},
    {"label": "Turkish", "value": "tr"},
    {"label": "Ukrainian", "value": "uk"},
    {"label": "Vietnamese", "value": "vi"},
    {"label": "Chinese (Simplified)", "value": "zh-cn"},
    {"label": "Chinese (Traditional)", "value": "zh-tw"},
]

SUPPORTED_LANGUAGES = tuple(option["value"] for option in LANGUAGES_OPTIONS)
