;;; Directory Local Variables            -*- no-byte-compile: t -*-
;;; For more information see (info "(emacs) Directory Variables")

((nil . ((eglot-workspace-configuration . (:pyright (:reportUnusedImport t :reportMissingImports t :enableReachabilityAnalysis nil)))
         (apheleia-formatter . (isort black)))))
